#!/bin/sh

echo ""
echo "IBM Business Process Manager 8.5.0 Migration"
echo ""

usage() {
  echo -e -n "\n"
  echo "Starts or continues the upgrade."
  echo -e -n "\n"
  echo "Usage:"
  echo -e -n "\n"
  echo "   `basename ${0}` [options...]"
  echo -e -n "\n"
  echo "Example:"
  echo "   Build the mapping file:"
  echo "      upgrade_6x.bat -c upgrade.properties -b map.xml -profileName DmgrProfileName -deConfigFile /temp/deconfig.xml"
  echo "   Upgrade the runtime environment:"
  echo "      upgrade_6x.bat -c upgrade.properties -profileName DmgrProfileName -deConfigFile /temp/deconfig.xml map.xml"
  echo -e -n "\n"
  echo "Options:"
  echo "   -?, -help                             This help message"
  echo "   -c, -config <file>                    Upgrade config properties file, defaults to upgrade.properties"
  echo "   -s, -status                           Shows the currently executing phase along with any additional information (does not continue upgrade)"
  echo "   -b, -buildSettingsFile <file>         Creates a base upgrade settings file that includes base process instance map to be filled in"
  echo "   -cleanAndRestart                      Restart the upgrade (cleans the DBs and starts the copy of data again)"
  echo "   -profileName <name>                   Profile name"
  echo "   -nodeName <name>                      Node name in ND environment (optional)"
  echo "   -serverName <name>                    Server name in ND environment (optional)"
  echo "   -perfNodeName <name>                  Node name of Performance Data Warehouse in ND environment (optional)"
  echo "   -perfServerName <name>                Server name of Performance Data Warehouse in ND environment (optional)"
  echo "   -g, -generateAdhocReport <path>       Create the installation package for Ad-Hoc Reports on target process-center (In process-center off-line mode, and want to migrate Ad-Hoc reports, you need to generate this package first and place it into install-app folder before migration.)"
  echo "   -deConfigFile  <full path>            Full path of DE config file"
  echo -e -n "\n"
  exit $1
}

validateParam() {
  if [ "$2" = "" ]
  then
    echo "No value specified for parameter $1"
    usage 1
  fi
}

SCRIPT_DIR=`dirname ${0}`
ORIG_DIR=`pwd`
BIN_DIR=$SCRIPT_DIR/../../../../../bin
cd $BIN_DIR
. ./setupCmdLine.sh

cd $SCRIPT_DIR

if [ "${USER_INSTALL_ROOT:=}" = "" ]; then
  echo -e -n "\n"
  echo "Profile does not exist."
  echo -e -n "\n"
  usage 1
fi

if [ -f ${JAVA_HOME}/bin/java ]; then
  JAVA_EXE="${JAVA_HOME}/bin/java"
else
  JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

TARGET="upgrade"
WAS_HOME_PROP="-Dwas.install.root=${WAS_HOME}"
NODE_NAME_PROP=
SERVER_NAME_PROP=
CONFIG_PROP="-Dteamworks.upgrade.settingsFile=upgrade.properties"
MAPPING_PROP="-Dteamworks.upgrade.configFile=config.xml"
LOGGING_PROP="-Dcom.lombardisoftware.ant.JULDefaultLogger.level=DEBUG -Djava.util.logging.config.file=$SCRIPT_DIR/logging.properties -Dtw.log4j.init=false"
LOGGING_FILTER_PROP="-Dcom.lombardi.logging.StringFilter.excludes=equals(WKSP0500);equals(WSVR0801I);equals(WSVR0072W);startsWith(ssl.);startsWith(security.);startsWith(FFDC1003I);regexp(^Class.+loaded.from.ant.loader..parentFirst.);regexp(^Class.+loaded.from.parent.loader..parentFirst.);regexp(^Finding.class.+\..+\..+);regexp(^Loaded.from.+\.jar..+\.class$)"
LOGGING_PROP="$LOGGING_PROP $LOGGING_FILTER_PROP"
ANT_PROPS="-q -e -logger com.lombardisoftware.ant.JULDefaultLogger"

UPGRADE_RESOURCE_DIR=${WAS_HOME}/BPM/Lombardi/tools/upgrade/upgrade_6x/resources
APP_JAVA_POLICY="-Djava.security.policy=file:${UPGRADE_RESOURCE_DIR}/java.policy"

ENABLE_DEBUG=false

if [ $ENABLE_DEBUG = true ]; then
   DEBUG_PROP="-Xdebug -Xrunjdwp:transport=dt_socket,address=7780,server=y,suspend=y"   
else
   DEBUG_PROP=
fi



FINISHED='0'
until [ $FINISHED = '1' ]
do
  case "$1" in
    '-?'|'-help')
      usage 0
      ;;
    '-c'|'-config')
      validateParam $1 $2
      CONFIG_PROP="-Dteamworks.upgrade.settingsFile=$2"
      shift;shift
      ;;
    '-cleanAndRestart')
      TARGET="upgrade-restart"
      shift
      ;;
    '-s'|'-status')
      TARGET="upgrade-status"
      shift
      ;;
    '-b'|'-buildSettingsFile')
      validateParam $1 $2
      TARGET="create-upgrade-mapping-file"
      MAPPING_PROP="-Dteamworks.upgrade.configFile=$2"
      shift;shift
      ;;
    '-g'|'-generateAdhocReport')
      validateParam $1 $2
      TARGET="generate-adhoc-reports-package"
      ADHOC_PACKAGE_PATH="-DadhocPackagePath=$2"
      shift;shift
	  ;;
    '-profileName')
      validateParam $1 $2
      PROC_SERVER_PROFILE_PROP="-DprocsrvProfileName=$2"
      shift;shift
      ;;
    '-nodeName')
      validateParam $1 $2
      NODE_NAME_PROP="-DnodeName=$2"
      shift;shift
      ;;
    '-serverName')
      validateParam $1 $2
      SERVER_NAME_PROP="-DserverName=$2"
      shift;shift
      ;;
    '-perfNodeName')
      validateParam $1 $2
      PERF_NODE_NAME_PROP="-DperfNodeName=$2"
      shift;shift
      ;;
    '-perfServerName')
      validateParam $1 $2
      PERF_SERVER_NAME_PROP="-DperfServerName=$2"
      shift;shift
      ;;
    '-deConfigFile')
      validateParam $1 $2
      DE_CONFIG_FILE_PROP="-DdeConfigFile=$2"
      shift;shift
      ;;  
    *)
      FINISHED='1'
      ;;
  esac
done

if [ "$#" -gt "1" ]; then
  echo "Invalid parameter: $1, please correct it and try again."
  usage 1;
fi
if [ "$#" = "1" -a -n "$1" ]; then
  MAPPING_PROP="-Dteamworks.upgrade.configFile=$1"
fi

CLASSPATH=$SCRIPT_DIR
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/resources
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant.jar
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant-launcher.jar
CLASSPATH=$CLASSPATH:$SCRIPT_DIR/lib/ant-nodeps.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/ant-contrib.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/twant.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/langutil.jar
CLASSPATH=$CLASSPATH:$WAS_HOME/BPM/Lombardi/lib/commons-logging.jar

$JAVA_EXE -cp $CLASSPATH $WAS_HOME_PROP $USER_INSTALL_PROP $APP_JAVA_POLICY $NODE_NAME_PROP $SERVER_NAME_PROP $PERF_NODE_NAME_PROP $PERF_SERVER_NAME_PROP $DE_CONFIG_FILE_PROP $PROC_SERVER_PROFILE_PROP $ADHOC_PACKAGE_PATH $CONFIG_PROP $MAPPING_PROP $LOGGING_PROP $DEBUG_PROP org.apache.tools.ant.Main -buildfile $SCRIPT_DIR/upgrade.xml $ANT_PROPS $TARGET

if [ "$?" -ne "0" ]
then
  exit $?
fi
